#ifndef NT2_INCLUDE_FUNCTIONS_BITS_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_BITS_HPP_INCLUDED

#include <nt2/bitwise/include/functions/bits.hpp>

#endif
